from setuptools import setup, find_packages


setup(
    name='simple_hello_new',
    version='0.0.1',
    license='MIT',
    author="Kek Shmek",
    author_email='email@example.com',
    keywords='example project',

)